==> style-o-matic-1.1.3.tgz: package/es/components/Radio/Radio.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import classNames from "classnames";
import { CoreComponent, getPropTypesA11y, getCorePropDefaults, getValidProps, ROLE } from "../../lib";
import "./Radio.css";

var Radio = (_temp2 = _class = function (_CoreComponent) {
  _inherits(Radio, _CoreComponent);

  function Radio() {
    var _temp, _this, _ret;

    _classCallCheck(this, Radio);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _CoreComponent.call.apply(_CoreComponent, [this].concat(args))), _this), _this.getValue = function () {
      var value = null;
      _this.fields.map(function (field) {
        if (field.checked) {
          value = field.value;
        }
        return null;
      });
      return value;
    }, _this.handleOnRef = function (e) {
      _this.fields.push(e);
    }, _this.fields = [], _this.valid = true, _this.renderKey = "radio_" + _this.props.uuid, _this.renderLabel = function (id, label, required) {
      if (label !== null) {
        var validationClass = required ? "label required-label" : "label";
        return React.createElement(
          "span",
          { key: "label_" + _this.state.renderKey, className: validationClass },
          label
        );
      }
      return React.createElement("span", null);
    }, _this.renderRadioOptions = function (parentKey, options) {
      var output = [];
      for (var i = 0; i < options.length; i += 1) {
        var optionData = options[i];
        var optionId = parentKey + "_" + i;
        output.push(React.createElement(
          "label",
          { key: optionId, htmlFor: optionId },
          React.createElement("input", {
            type: "radio",
            id: optionId,
            name: parentKey,
            value: optionData.Value,
            ref: _this.handleOnRef
          }),
          optionData.Label
        ));
      }
      return output;
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Radio.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        className = _getValidProps.className,
        id = _getValidProps.id,
        name = _getValidProps.name,
        required = _getValidProps.required,
        disabled = _getValidProps.disabled,
        label = _getValidProps.label,
        children = _getValidProps.children,
        options = _getValidProps.options,
        props = _getValidProps.props;

    delete props.name;
    delete props.id;

    var fieldId = name || id || this.renderKey;
    var preParsedClass = "ui-radio";
    var wrapperClasses = {
      disabled: disabled,
      invalid: !this.valid
    };

    this.fields = [];

    return React.createElement(
      "div",
      { className: className },
      this.renderLabel(fieldId, label, required),
      React.createElement(
        Component,
        _extends({
          key: this.renderKey
        }, props, {
          className: classNames(preParsedClass, wrapperClasses)
        }),
        this.renderRadioOptions(fieldId, options),
        children
      )
    );
  };

  return Radio;
}(CoreComponent), _class.propTypes = getPropTypesA11y({
  id: "string!",
  required: "bool",
  label: "string",
  validator: "func",
  options: "array"
}), _class.defaultProps = getCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.INPUT,
  type: "text",
  checked: false,
  required: false,
  label: null,
  validator: null,
  validPattern: null,
  maskPattern: null,
  options: []
}), _temp2);


export default Radio;

==> style-o-matic-1.1.5.tgz: package/es/components/Radio/Radio.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import classNames from "classnames";
import { CoreComponent, setPropTypesA11y, setCorePropDefaults, getValidProps, ROLE } from "../../lib";
import "./Radio.css";

var Radio = (_temp = _class = function (_CoreComponent) {
  _inherits(Radio, _CoreComponent);

  function Radio(props) {
    _classCallCheck(this, Radio);

    var _this = _possibleConstructorReturn(this, _CoreComponent.call(this, props));

    _this.getValue = function () {
      return _this.value;
    };

    _this.getCheckedValue = function () {
      var value = null;
      _this.fields.map(function (field) {
        if (field.checked) {
          value = field.value;
        }
        return null;
      });
      return value;
    };

    _this.handleOnChange = function (e) {
      _this.value = e.target.value;
      if (_this.props.onChange) {
        _this.props.onChange(e);
      }
    };

    _this.handleOnRef = function (e) {
      _this.fields.push(e);
    };

    _this.renderLabel = function (fieldId, label, required) {
      if (label !== null) {
        var validationClass = required ? "label required-label" : "label";
        return React.createElement(
          "span",
          { key: "label_" + fieldId, className: validationClass },
          label
        );
      }
      return React.createElement("span", null);
    };

    _this.renderRadioOptions = function (fieldId, options) {
      var output = [];
      for (var i = 0; i < options.length; i += 1) {
        var optionData = options[i];
        var optionId = fieldId + "_" + i;
        output.push(React.createElement(
          "label",
          { key: optionId, htmlFor: optionId },
          React.createElement("input", {
            type: "radio",
            id: optionId,
            name: fieldId,
            onChange: _this.handleOnChange,
            value: optionData.value,
            ref: _this.handleOnRef
          }),
          optionData.label
        ));
      }
      return output;
    };

    _this.value = props.value;
    if (!_this.value) {
      _this.value = props.options[0] ? props.options[0].value : "";
    }
    _this.fields = [];
    _this.valid = true;
    _this.renderKey = "radio_" + props.uuid;
    return _this;
  }

  Radio.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        className = _getValidProps.className,
        id = _getValidProps.id,
        name = _getValidProps.name,
        required = _getValidProps.required,
        disabled = _getValidProps.disabled,
        label = _getValidProps.label,
        children = _getValidProps.children,
        options = _getValidProps.options,
        props = _getValidProps.props;

    delete props.name;
    delete props.id;

    var fieldId = name || id || this.renderKey;
    var preParsedClass = "ui-radio";
    var wrapperClasses = {
      disabled: disabled,
      invalid: !this.valid
    };

    this.fields = [];

    return React.createElement(
      "div",
      { className: className },
      this.renderLabel(fieldId, label, required),
      React.createElement(
        Component,
        _extends({
          key: this.renderKey
        }, props, {
          className: classNames(preParsedClass, wrapperClasses)
        }),
        this.renderRadioOptions(fieldId, options),
        children
      )
    );
  };

  return Radio;
}(CoreComponent), _class.propTypes = setPropTypesA11y({
  id: "string!",
  required: "bool",
  label: "string",
  validator: "func",
  options: "array"
}), _class.defaultProps = setCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.INPUT,
  type: "text",
  checked: false,
  required: false,
  label: null,
  validator: null,
  validPattern: null,
  maskPattern: null,
  options: []
}), _temp);


export default Radio;
